<?php
 
/**
 *  Class for compare two dates from a form and verify if them follows the 
 * condition passed
 * @package frontend
 * @subpackage lib
 * @author Diego Cebrián
 */

/**
 *  Class for compare two dates from a form and verify if them follows the 
 * condition passed
 * 
 * @package frontend
 * @subpackage lib
 * @author Diego Cebrián
 *
 */
class myDateCompareValidator extends sfValidator
{

  /**
   * Function to start the validation class. <br />
   * 
   * The parameters array is composed of:<br />
   * 
   * <ul>
   * 
   *  <li>check_date: the name of the field of the form to compare with </li>
   * 
   *  <li>compare_error: The string that will be shown when the condition is 
   *    not raised </li>
   * 
   *  <li>operator: the operator comparison value. Te posible values are: '>',
   *    '>=', '<', '<=', '=', '!='  </li>
   * 
   * </ul>
   *
   * @param unknown_type $context
   * @param array $parameters
   * @return boolean
   */
  public function initialize($context, $parameters = null)
  {
    // initialize parent
    parent::initialize($context, $parameters);
 
    // set defaults
    $this->setParameter('date_error', 'Invalid date');
 
    $this->getParameterHolder()->add($parameters);
 
    return true;
  }
 
  /**
   * Function that execute the validation with the parameters passed in 
   * initialize, except the value, that is passed here by the validation helper, 
   * and it's value is the value filled in the field form to check
   *
   * @param string &$value
   * @param string &$error
   * @return boolean
   */
  public function execute(&$value, &$error)
  { 
  	//obtain the culture for the operations       
  	$culture = $this->getContext()->getUser()->getCulture();
  	
  	//get the dates and the operator
  	$date=$value;
    $checkDateParam = $this->getParameter('check_date');
    $checkDate = $this->getContext()->getRequest()->getParameter($checkDateParam);
    $operator = $this->getParameter('operator', '==');    // default ==
    $operator = trim($operator, '\'');

    //transform date to the correct culture and obtain the tiem to comapre
    list($d, $m, $y) = sfI18N::getDateForCulture($date, $culture);
    $date = strtotime("$y-$m-$d 00:00");
   	list($d, $m, $y) = sfI18N::getDateForCulture($checkDate, $culture);
  	$checkDate = strtotime("$y-$m-$d 00:00");
    
  	//compare the dates with the operator
    $evalStr = "if ($date $operator $checkDate) { return true; } else { return false; }";
    if ($checkDate && !eval($evalStr)) {
    	$error = $this->getParameter('compare_error');
    	return false;
    }
        
    return true;
  	
  }
}