<?php
/**
 *  Class for compare two dates , one from a form and other from a database, and
 * verify if them follows the condition passed
 * @package frontend
 * @subpackage lib
 * @author Diego Cebrián
 */
 
/**
 * Class for compare two dates , one from a form and other from a database, and
 * verify if them follows the condition passed
 * 
 * @package frontend
 * @subpackage lib
 * @author Diego Cebrián
 */
class myDbDateCompareValidator extends sfValidator
{

  /**
   * Function to start the validation class. <br />
   * 
   * The parameters array is composed of (+ are mandatory, * one of this is 
   * mandatory): <br />
   * <ul> 
   *  
   *  <li>+class_name: The class where the date is stored</li>
   * 
   *  <li>+date_db: the date column name to compare in the db table</li>
   * 
   *  <li>+date_php: the date to compare name in php class</li>
   * 
   *  <li>+found_error: the error message to return to the user</li>
   * 
   *  <li>+search_type: This is the condition to return false. The posible 
   *    values for search_type (without colomns):
   * 
   *    <ul>
   *      <li>'NOT_EQUAL'</li>
   *      <li>'GREATER_THAN'</li>
   *      <li>'LESS_THAN'</li>
   *      <li>'GREATER_EQUAL'</li>
   *      <li>'LESS_EQUAL'</li>
   *      <li>Empty value is Equal</li>
   *    </ul>
   * 
   *  </li>
   *  <li>-exception_id: if there is an exception row in the table (Example: in 
   *    edition the row edited), it takes the field of the form which contains 
   *    it)</li>
   *  <li>-criteria: some additional criteria for propel selection. This 
   *  aditional criteria must be noted this way:<br />
   *  <ul>
   *    <li>criteria:
   *      <ul>
   *        <li>criteria1:
   *         <ul>
   *           <li>+column: column name for criteria checking
   *           <li>*value: value for criteria
   *           <li>*field: field of the form where the value is defined
   *           <li>-criteria: criteria pattern (see symfony or propel documentation)
   *         </ul>
   *        </li>
   *      </ul>
   *    </li>
   *  </ul>
   *  </li>
   * </ul>
   * 
   * The date passed by $value is searched in the table 'class_name'.<br />
   * 
   * The table must have a colum called 'column_filter', and the validator only
   * will compare with the fields that have in this column 'column_value'.<br/>
   *     
   * To get the true answer (and can execute without error) there must not be 
   * any field of the column * 'column' that can be find using the search_type.
   * <br />
   *
   * @param unknown_type $context
   * @param array $parameters
   * @return boolean
   */
  public function initialize($context, $parameters = null)
  {
    // initialize parent
    parent::initialize($context, $parameters);
 
    // set defaults
    $this->setParameter('date_error', 'Invalid date');
 
    $this->getParameterHolder()->add($parameters);
 
    return true;
  }
 
  /**
   * Function that execute the validation with the parameters passed in 
   * initialize, except the value, that is passed here by the validation helper, 
   * and it's value is the value filled in the field form to check
   *
   * @param string &$value
   * @param string &$error
   * @return boolean
   */
  public function execute(&$value, &$error)
  {
 
    //obtain the culture for the operations       
    $culture = $this->getContext()->getUser()->getCulture();
    
    //Recover table name and checked columns
    $className = $this->getParameter('class_name');
    $dateDb = $this->getParameter('date_db');
    $datePHP= $this->getParameter('date_php');
   
    //recover data from the form
    $date = $value;
    if($this->getParameter('exception_id')){
      $exceptionIdField= $this->getParameter('exception_id');
      $exceptionId=$this->getContext()->getRequest()->getParameter($exceptionIdField);
    }

    //transforming the dates to MySQL format
    list($d, $m, $y) = sfI18N::getDateForCulture($date, $culture);
    $date = strtotime("$y-$m-$d 00:00");
    
    
    //get the search type
    if($this->getParameter('search_type')){
      $search=$this->getParameter('search_type');
    }
    
    //defining the common search criteria
    
    $c= new Criteria();
    if($this->getParameter('criteria')){
      foreach($this->getParameter('criteria') as $criteria){
        if(isset($criteria['field'])){
          if(isset($criteria['criteria'])){
            eval ('$c->add('.$className.'Peer::'.$criteria['column'].', '.$this->getContext()->getRequest()->getParameter($criteria['field']).', '.$criteria['criteria'] .');');
          }else{
            eval ('$c->add('.$className.'Peer::'.$criteria['column'].', '.$this->getContext()->getRequest()->getParameter($criteria['field']).');');
          }
        }else{
          if(isset($criteria['criteria'])){
            eval ('$c->add('.$className.'Peer::'.$criteria['column'].', '.$criteria['value'].', '.$criteria['criteria'] .');');
          }else{
            eval ('$c->add('.$className.'Peer::'.$criteria['column'].', '.$criteria['value'].');');
          }
        }
      }
    }
    if($this->getParameter('exception_id')){
      eval ('$c->add('.$className.'Peer::ID, '.$exceptionId.', Criteria::NOT_EQUAL);');
    }
    
    //checking
    if($this->getParameter('search_type')){
      eval ('$c->add('.$className.'Peer::'.$dateDb.', '.$date.', Criteria::'.$search.');');
    }else{
      eval ('$c->add('.$className.'Peer::'.$dateDb.', '.$date.');');
    }
    eval ('$foundDate= '.$className.'Peer::doSelectOne($c);');
    
    
    //determine the result
    if ($foundDate){
      $format = 'd';
      $dateFormats[$culture] = new sfDateFormat($culture);
      $charset = sfConfig::get('sf_charset');
      eval('$returnDate= $dateFormats[$culture]->format($foundDate->get'.$datePHP.'(), $format, null, $charset);');
      $error = $this->getContext()->getI18N()->__($this->getParameter('found_error')).' '.$returnDate;
      return false;
    }
    return true;
  }
}