<?php
/**
 *  Class for checking the name and password of an user to login
 * @package frontend
 * @subpackage lib
 * @author Diego Cebrián
 */
 
/**
 *  Class for checking the name and password of an user to login
 * 
 * @package frontend
 * @subpackage lib
 * @author Diego Cebrián
 */
class myLoginValidator extends sfValidator
{

  /**
   * Function to start the validation class. <br />
   * 
   * The parameters array is composed of: <br />
   *
   * <ul>
   *  <li>password: the password to verify</li>
   *  <li>login_error: the error message to send the controler and inform 
   *    the user</li>
   * </ul>
   * 
   * @param unknown_type $context
   * @param array $parameters
   * @return boolean
   */
  public function initialize($context, $parameters = null)
  {
    // initialize parent
    parent::initialize($context);
 
    // set defaults
    $this->setParameter('login_error', 'Invalid input');
 
    $this->getParameterHolder()->add($parameters);
 
    return true;
  }
 
  /**
   * Function that execute the validation with the parameters passed in 
   * initialize, except the value, that is passed here by the validation helper, 
   * and it's value is the value filled in the field form to check.<br/>
   * Value: nickname for the user.
   *
   * @param string &$value
   * @param string &$error
   * @return boolean
   */
  public function execute(&$value, &$error)
  {
  	//obtaining the password and the user name from the parameters
    $password_param = $this->getParameter('password');
    $password = $this->getContext()->getRequest()->getParameter($password_param);
    $login = $value;
 
    // anonymous is not a real user
    if ($login == 'anonymous')
    {
      $error = $this->getParameter('login_error');
      return false;
    }
 
    //search the user with this name
    $c = new Criteria();
    $c->add(UserPeer::NICKNAME, $login);
    $user = UserPeer::doSelectOne($c);
 
    // does nickname exists?
    if ($user)
    {
      // is password OK?
      if (sha1($user->getSalt().$password) == $user->getSha1Password())
      {
		    $this->getContext()->getUser()->signIn($user);
        return true;
      }
    }
 
    $error = $this->getParameter('login_error');
    return false;
  }
}