<?php
/**
 * Class for administrate login, logout, roles, permisions, credentials, and 
 * recovering information from the user logged in.
 * 
 * @package frontend
 * @subpackage lib
 * @author Diego Cebrián
 */

/**
 * Class for administrate login, logout, roles, permisions, credentials, and 
 * recovering information from the user logged in.
 * 
 * @package frontend
 * @subpackage lib
 * @author Diego Cebrián
 */

class myUser extends sfBasicSecurityUser
{
	/**
	 * Clear the credentials and the logged in session
	 *
	 */
	public function signOut(){
		$this->getAttributeHolder()->removeNamespace('athlete');
		$this->clearCredentials();
		$this->setAuthenticated(false);
	}

	/**
	 * Make the process of registering the session with the corresponding 
	 * credentials
	 *
	 * @param User $user
	 */
	public function signIn($user)
	{

		$this->setAuthenticated(true);
		$this->setAttribute('nickname', $user->getNickname(), 'athlete');
		$this->setAttribute('user_id', $user->getId(), 'athlete');

		//check if the user is an admin
		if($user->getIsAdmin()){
			$this->addCredential('is_admin');
			$this->setAttribute('is_admin', $user->getIsAdmin(), 'athlete');
		}
		else{
			$this->setAttribute('is_admin', $user->getIsAdmin(), 'athlete');
		}

		//check if the user is a coach
		if($user->getIsCoach()){
			$this->addCredential('is_coach');
			$this->setAttribute('is_coach', $user->getIsCoach(), 'athlete');
		}
		else{
			$this->setAttribute('is_coach', $user->getIsCoach(), 'athlete');
		}

		//check if the user is an athlete
		if($user->getIsAthlete()){
			$this->addCredential('is_athlete');
			$this->setAttribute('is_athlete', $user->getIsAthlete(), 'athlete');
		}
		else{
			$this->setAttribute('is_athlete', $user->getIsAthlete(), 'athlete');
		}
		if($user->getCulture()!=null){
			$this->setCulture($user->getCulture());
		}
	}

	/**
	 * Return the id of the User Loged in
	 *
	 * @return int
	 */
	public function getUserId() {
		return $this->getAttribute('user_id', '', 'athlete');
	}


	/**
	 * Return the object user logged in
	 *
	 * @return User
	 */
	public function getUser()
	{
		return UserPeer::retrieveByPk($this->getUserId());
	}

	/**
	 * Retrieve the user nickname from the present user
	 *
	 * @return string
	 */
	public function getNickname()
	{
		return $this->getAttribute('nickname', '', 'athlete');
	}

	/**
	 * Function to retrieve if the user logged in is admin
	 *
	 * @return boolean
	 */
	public function getIsAdmin()
	{
		return $this->getAttribute('is_admin', '', 'athlete');
	}

	/**
	 * Function to retrieve if the user logged in is an athlete
	 *
	 * @return boolean
	 */
	public function getIsAthlete()
	{
		return $this->getAttribute('is_athlete', '', 'athlete');
	}

	/**
	 * Function to retrieve if the user logged in is a coach
	 *
	 * @return boolean
	 */
	public function getIsCoach()
	{
		return $this->getAttribute('is_coach', '', 'athlete');
	}

}
