<?php
/**
 * sfCustomUniqueValidator checks if a record exist in the database 
 * @package frontend
 * @subpackage lib
 * @author     Joachim Martin
 */

  /**
 * sfCustomUniqueValidator checks if a record exist in the database 
 * 
 * 
 * @package frontend
 * @subpackage lib
 * @author     Joachim Martin
 * @date       15/06/2007
 */
 
class sfCustomUniqueValidator extends sfValidator {
 
   
   /**
   * Function to start the validation class. <br />
   * 
   * The parameters array is composed of: <br />
   *
   * <ul>
   *  <li>class: the class on which the search is performed</li>
   *  <li>nb_fields: the number of fields on which the comparison is done</li>
   *  <li>field_1: First field of the comparison</li>
   *  <li>field_2: Other country for the comparison</li>
   * </ul>
   * 
   * @param unknown_type $context
   * @param array $parameters
   * @return boolean
   */
    public function initialize ($context, $parameters = null) {
        // initialize parent
        parent::initialize($context);
 
        //Set default parameters value
        $this->setParameter('custom_unique_error','The value is not unique');
 
        $this->getParameterHolder()->add($parameters);
 
        // check parameters
        if (!$this->getParameter('class'))
        {
          throw new sfValidatorException('The "class" parameter is mandatory for the sfCustomUniqueValidator validator.');
        }
 
        if (!$this->getParameter('nb_fields'))
        {
          throw new sfValidatorException('The "nb_fields" parameter is mandatory for the sfCustomUniqueValidator validator.');
        }
 
        return true;
    }
   /**
   * Executes this validator.
   *
   * @param mixed A file or parameter value/array
   * @param error An error message reference
   *
   * @return bool true, if this validator executes successfully, otherwise false
   */
 
    public function execute(&$value, &$error) {
 
        $className  = $this->getParameter('class').'Peer';
 
        //Get fields number
        $nb_fields = $this->getParameter('nb_fields');
 
        //Define new criteria       
        $c = new Criteria();
        
    
		    if($this->getParameter('exception_id')){
		      $exceptionIdField= $this->getParameter('exception_id');
		      $exceptionId=$this->getContext()->getRequest()->getParameter($exceptionIdField);
          eval ('$c->add('.$className.'::ID, '.$exceptionId.', Criteria::NOT_EQUAL);');
		    }
 
        //Loop on the fields
        for($i = 1; $i <= $nb_fields ; $i++) {
            //Retrieve field_$i 
            $check_param = $this->getParameterHolder()->get("field_$i");
            $check_value = $this->getContext()->getRequest()->getParameter($check_param);
 
            //If check value defined        
            if ($check_value != '') {   
                //Adding field to the criteria
                $columnName = call_user_func(array($className, 'translateFieldName'), $check_param, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_COLNAME);
                $c->add($columnName, $check_value);
            }
        }
 
        $object = call_user_func(array($className, 'doSelectOne'), $c);
 
        if ($object)
        {
          $tableMap = call_user_func(array($className, 'getTableMap'));
          foreach ($tableMap->getColumns() as $column)
          {
            if (!$column->isPrimaryKey())
            {
              continue;
            }
 
            $method = 'get'.$column->getPhpName();
            $primaryKey = call_user_func(array($className, 'translateFieldName'), $column->getPhpName(), BasePeer::TYPE_PHPNAME, BasePeer::TYPE_FIELDNAME);
            if ($object->$method() != $this->getContext()->getRequest()->getParameter($primaryKey))
            {
              $error = $this->getParameter('custom_unique_error');
 
              return false;
            }
          }
        }
 
        return true;
    } 
 
}