
# This is a fix for InnoDB in MySQL >= 4.1.x
# It "suspends judgement" for fkey relationships until are tables are set.
SET FOREIGN_KEY_CHECKS = 0;

#-----------------------------------------------------------------------------
#-- unit_type
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `unit_type`;


CREATE TABLE `unit_type`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`global_description` VARCHAR(250),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- unit_type_i18n
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `unit_type_i18n`;


CREATE TABLE `unit_type_i18n`
(
	`id` INTEGER  NOT NULL,
	`culture` VARCHAR(7)  NOT NULL,
	`description` VARCHAR(250),
	PRIMARY KEY (`id`,`culture`),
	CONSTRAINT `unit_type_i18n_FK_1`
		FOREIGN KEY (`id`)
		REFERENCES `unit_type` (`id`)
		ON DELETE CASCADE
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- unit
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `unit`;


CREATE TABLE `unit`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`symbol` VARCHAR(25),
	`unit_type_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `unit_FI_1` (`unit_type_id`),
	CONSTRAINT `unit_FK_1`
		FOREIGN KEY (`unit_type_id`)
		REFERENCES `unit_type` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- unit_i18n
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `unit_i18n`;


CREATE TABLE `unit_i18n`
(
	`id` INTEGER  NOT NULL,
	`culture` VARCHAR(7)  NOT NULL,
	`description` VARCHAR(250),
	PRIMARY KEY (`id`,`culture`),
	CONSTRAINT `unit_i18n_FK_1`
		FOREIGN KEY (`id`)
		REFERENCES `unit` (`id`)
		ON DELETE CASCADE
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- conversion_factor
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `conversion_factor`;


CREATE TABLE `conversion_factor`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`origin_id` INTEGER  NOT NULL,
	`destiny_id` INTEGER  NOT NULL,
	`conversion_factor` DOUBLE,
	PRIMARY KEY (`id`),
	UNIQUE KEY `relation` (`origin_id`, `destiny_id`),
	CONSTRAINT `conversion_factor_FK_1`
		FOREIGN KEY (`origin_id`)
		REFERENCES `unit` (`id`),
	INDEX `conversion_factor_FI_2` (`destiny_id`),
	CONSTRAINT `conversion_factor_FK_2`
		FOREIGN KEY (`destiny_id`)
		REFERENCES `unit` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- season
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `season`;


CREATE TABLE `season`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`start_at` DATE,
	`last_day_at` DATE,
	`user_id` INTEGER,
	`volume_unit_type_id` INTEGER,
	`theoric_volume` DOUBLE,
	`reported_volume` DOUBLE,
	`volume_unit_id` INTEGER,
	`volume_show_unit_id` INTEGER,
	`theoric_intensity1` DOUBLE,
	`reported_intensity1` DOUBLE,
	`intensity1_low_limit` DOUBLE,
	`intensity1_high_limit` DOUBLE,
	`theoric_intensity2` DOUBLE,
	`reported_intensity2` DOUBLE,
	`intensity2_high_limit` DOUBLE,
	`theoric_intensity3` DOUBLE,
	`reported_intensity3` DOUBLE,
	`intensity3_high_limit` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `season_FI_1` (`user_id`),
	CONSTRAINT `season_FK_1`
		FOREIGN KEY (`user_id`)
		REFERENCES `user` (`id`),
	INDEX `season_FI_2` (`volume_unit_type_id`),
	CONSTRAINT `season_FK_2`
		FOREIGN KEY (`volume_unit_type_id`)
		REFERENCES `unit_type` (`id`),
	INDEX `season_FI_3` (`volume_unit_id`),
	CONSTRAINT `season_FK_3`
		FOREIGN KEY (`volume_unit_id`)
		REFERENCES `unit` (`id`),
	INDEX `season_FI_4` (`volume_show_unit_id`),
	CONSTRAINT `season_FK_4`
		FOREIGN KEY (`volume_show_unit_id`)
		REFERENCES `unit` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- macrocycle
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `macrocycle`;


CREATE TABLE `macrocycle`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`start_at` DATE,
	`last_day_at` DATE,
	`season_id` INTEGER,
	`theoric_volume` DOUBLE,
	`reported_volume` DOUBLE,
	`theoric_intensity1` DOUBLE,
	`reported_intensity1` DOUBLE,
	`theoric_intensity2` DOUBLE,
	`reported_intensity2` DOUBLE,
	`theoric_intensity3` DOUBLE,
	`reported_intensity3` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `macrocycle_FI_1` (`season_id`),
	CONSTRAINT `macrocycle_FK_1`
		FOREIGN KEY (`season_id`)
		REFERENCES `season` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- mesocycle
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `mesocycle`;


CREATE TABLE `mesocycle`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`start_at` DATE,
	`last_day_at` DATE,
	`macrocycle_id` INTEGER,
	`theoric_volume` DOUBLE,
	`reported_volume` DOUBLE,
	`theoric_intensity1` DOUBLE,
	`reported_intensity1` DOUBLE,
	`theoric_intensity2` DOUBLE,
	`reported_intensity2` DOUBLE,
	`theoric_intensity3` DOUBLE,
	`reported_intensity3` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `mesocycle_FI_1` (`macrocycle_id`),
	CONSTRAINT `mesocycle_FK_1`
		FOREIGN KEY (`macrocycle_id`)
		REFERENCES `macrocycle` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- microcycle
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `microcycle`;


CREATE TABLE `microcycle`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`start_at` DATE,
	`last_day_at` DATE,
	`mesocycle_id` INTEGER,
	`theoric_volume` DOUBLE,
	`reported_volume` DOUBLE,
	`theoric_intensity1` DOUBLE,
	`reported_intensity1` DOUBLE,
	`theoric_intensity2` DOUBLE,
	`reported_intensity2` DOUBLE,
	`theoric_intensity3` DOUBLE,
	`reported_intensity3` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `microcycle_FI_1` (`mesocycle_id`),
	CONSTRAINT `microcycle_FK_1`
		FOREIGN KEY (`mesocycle_id`)
		REFERENCES `mesocycle` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- session
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `session`;


CREATE TABLE `session`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`date` DATE,
	`morning_session` INTEGER,
	`feedback` TEXT,
	`description` TEXT,
	`microcycle_id` INTEGER,
	`wake_up_hr` DOUBLE,
	`theoric_volume` DOUBLE,
	`reported_volume` DOUBLE,
	`theoric_intensity1` DOUBLE,
	`reported_intensity1` DOUBLE,
	`theoric_intensity2` DOUBLE,
	`reported_intensity2` DOUBLE,
	`theoric_intensity3` DOUBLE,
	`reported_intensity3` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `session_FI_1` (`microcycle_id`),
	CONSTRAINT `session_FK_1`
		FOREIGN KEY (`microcycle_id`)
		REFERENCES `microcycle` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- user
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `user`;


CREATE TABLE `user`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nickname` VARCHAR(50),
	`first_name` VARCHAR(100),
	`last_name` VARCHAR(100),
	`created_at` DATETIME,
	`born_at` DATETIME,
	`is_coach` INTEGER,
	`is_athlete` INTEGER,
	`coach_id` INTEGER,
	`is_admin` INTEGER,
	`is_male` INTEGER,
	`email` VARCHAR(100),
	`sha1_password` VARCHAR(40),
	`salt` VARCHAR(32),
	`country` VARCHAR(7),
	`language` VARCHAR(7),
	PRIMARY KEY (`id`),
	UNIQUE KEY `user_U_1` (`nickname`),
	UNIQUE KEY `user_U_2` (`email`),
	INDEX `user_FI_1` (`coach_id`),
	CONSTRAINT `user_FK_1`
		FOREIGN KEY (`coach_id`)
		REFERENCES `user` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- article
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `article`;


CREATE TABLE `article`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`author_id` INTEGER,
	`created_at` DATETIME,
	`updated_at` DATETIME,
	PRIMARY KEY (`id`),
	INDEX `article_FI_1` (`author_id`),
	CONSTRAINT `article_FK_1`
		FOREIGN KEY (`author_id`)
		REFERENCES `user` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- article_i18n
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `article_i18n`;


CREATE TABLE `article_i18n`
(
	`id` INTEGER  NOT NULL,
	`culture` VARCHAR(7)  NOT NULL,
	`title` VARCHAR(255),
	`text` TEXT,
	PRIMARY KEY (`id`,`culture`),
	CONSTRAINT `article_i18n_FK_1`
		FOREIGN KEY (`id`)
		REFERENCES `article` (`id`)
)Type=InnoDB;

# This restores the fkey checks, after having unset them earlier
SET FOREIGN_KEY_CHECKS = 1;
