<?php

/**
 * Subclass for representing a row from the 'microcycle' table.
 *
 *
 *

 * @package lib
 * @subpackage model
 * @author Diego Cebrián
 */ 

/**
 * @package lib
 * @subpackage model
 * @author Diego Cebrián
 *
 */
class Microcycle extends BaseMicrocycle
{
  /**
   * Method to return a description when echo variable is called
   *
   * @return description of the microcycle
   */
	public function __toString() {
		return parent::getDescription();
	}

	/**
	 * Method to save the microcycle and create the sessions that are inside
	 *
	 * @param conexiont to database $con
	 * @return booblean that tells if i was fine
	 */
	public function saveAndCreate($con=null){
		$con = Propel::getConnection();
		try
		{
			$con->begin();

			$ret = parent::save($con);

			//add all the sessions to the microcicle
			$date = new DateTime( $this->getStartAt('Y-m-d'));
			$endDate= new DateTime($this->getLastDayAt('Y-m-d'));
			while (strtotime(date_format($endDate,'Y-m-d'))>=strtotime(date_format($date,'Y-m-d'))) {
				$period=new Session();
				$period->setDate(date_format($date,'Y-m-d'));
				$period->setMorningSession(true);
				$this->addSession($period);
				$period->save($con);
				$date->modify("+1 day");
			}

			$con->commit();

			return $ret;
		}
		catch (Exception $e)
		{
			$con->rollback();
			throw $e;
		}
	}
 
  /**
   * Get the season for this period
   *
   * @return the object seeason that contents this period
   */
  public function getSeason() {
    return $this->getMesocycle()->getMacrocycle()->getSeason();
  }
  
  
  /**
   * @method getIntensity1LowLimit
   * @return Value of the Low limit of the first intensity level 
   */
  public function getIntensity1LowLimit() {
    return $this->getSeason()->getIntensity1LowLimit();
  }
  /**
   * @method getIntensity1HighLimit
   * @return Value of the High limit of the first intensity level 
   */
  public function getIntensity1HighLimit() {
    return $this->getSeason()->getIntensity1HighLimit();
  }

  /**
   * @method getIntensity2LowLimit
   * @return Value of the Low limit of the second intensity level 
   */
  public function getIntensity2LowLimit() {
    return $this->getSeason()->getIntensity2LowLimit();
  }
  /**
   * @method getIntensity2HighLimit
   * @return Value of the High limit of the second intensity level 
   */
  public function getIntensity2HighLimit() {
    return $this->getSeason()->getIntensity2HighLimit();
  }

  /**
   * @method getIntensity3LowLimit
   * @return Value of the Low limit of the third intensity level 
   */
  public function getIntensity3LowLimit() {
    return $this->getSeason()->getIntensity3LowLimit();
  }
  /**
   * @method getIntensity3HighLimit
   * @return Value of the High limit of the third intensity level 
   */
  public function getIntensity3HighLimit() {
    return $this->getSeason()->getIntensity3HighLimit();
  }
  /**
   * Retrieve the Volume unit from the correspondant season
   *
   * @return Unit
   */
  public function getVolumeUnit() {
    return $this->getSeason()->getVolumeUnit();
  }

  public function calculateReportedValues(){
    $intensity1=0;
    foreach ($this->getSessions() as $session){
      $intensity1+=$session->getReportedIntensity1(); 
    }
    parent::setReportedIntensity1($intensity1);
    $intensity2=0;
    foreach ($this->getSessions() as $session){
      $intensity2+=$session->getReportedIntensity2(); 
    }
    parent::setReportedIntensity2($intensity2);
    $intensity3=0;
    foreach ($this->getSessions() as $session){
      $intensity3+=$session->getReportedIntensity3(); 
    }
    parent::setReportedIntensity3($intensity3);
    $volume=0;
    foreach ($this->getSessions() as $session){
      $volume+=$session->getReportedVolume(); 
    }
    parent::setReportedVolume($volume);
    $this->save();
    $this->getMesocycle()->calculateReportedValues();
  }
}
